@@ -22,7 +22,8 @@
 #' @param tol maximum tolerance. Default is 'c(1e-04, 1e-05, 1e-05)'.
 #' @param maxiter max number of iterations. Default is
 #' '1000*round((1.25)^length(idparsopt))'.
-#' @param optimmethod method used for optimization. Default is 'simplex'.
+#' @param optimmethod method used for optimization. Available are simplex and
+#' subplex, default is 'subplex'. Simplex should only be used for debugging.
 #' @param num_cycles number of cycles of the optimization (default is 1).
 #' @param loglik_penalty the size of the penalty for all parameters; default is
 #'  0 (no penalty)
@@ -69,11 +70,10 @@
 #'parsfix <- c(0,0,0.01)
 #'tol <- c(1e-04, 1e-05, 1e-07)
 #'maxiter <- 1000 * round((1.25) ^ length(idparsopt))
-#'optimmethod <- 'simplex'
+#'optimmethod <- 'subplex'
 #'cond <- 'proper_cond'
 #'root_state_weight <- 'proper_weights'
 #'sampling_fraction <- c(1,1,1)
-#' \dontrun{
 #'model <- cla_secsse_ml(
 #'  phylotree,
 #'  traits,
@@ -89,7 +89,8 @@
 #'  tol,
 #'  maxiter,
 #'  optimmethod,
-#'  num_cycles = 1) }
+#'  num_cycles = 1,
+#'  verbose = FALSE)
 #' # [1] -90.97626
 #' @export
 cla_secsse_ml <- function(phy,
@@ -105,20 +106,20 @@ cla_secsse_ml <- function(phy,
                           sampling_fraction,
                           tol = c(1e-04, 1e-05, 1e-07),
                           maxiter = 1000 * round((1.25)^length(idparsopt)),
-                          optimmethod = "simplex",
+                          optimmethod = "subplex",
                           num_cycles = 1,
                           loglik_penalty = 0,
                           is_complete_tree = FALSE,
                           verbose = (optimmethod == "subplex"),
                           num_threads = 1,
-                          atol = 1e-12,
-                          rtol = 1e-12,
+                          atol = 1e-8,
+                          rtol = 1e-7,
                           method = "odeint::bulirsch_stoer") {
 
     structure_func <- NULL
     if (is.matrix(traits)) {
-        cat("you are setting a model where some species have more
-            than one trait state \n")
+        warning("you are setting a model where some species have more
+            than one trait state")
     }
 
     if (length(initparsopt) != length(idparsopt)) {
@@ -144,7 +145,7 @@ cla_secsse_ml <- function(phy,
 
     if (anyDuplicated(c(unique(sort(as.vector(idparslist[[3]]))),
                         idparsfix[which(parsfix == 0)])) != 0) {
-        cat("Note: you set some transitions as impossible to happen.", "\n")
+        warning("Note: you set some transitions as impossible to happen.")
     }
 
     if (is.matrix(idparslist[[1]])) {
@@ -160,8 +161,6 @@ cla_secsse_ml <- function(phy,
 
     see_ancestral_states <- FALSE
 
-    cat("Calculating the likelihood for the initial parameters ...", "\n")
-    utils::flush.console()
     trparsopt <- initparsopt / (1 + initparsopt)
     trparsopt[which(initparsopt == Inf)] <- 1
     trparsfix <- parsfix / (1 + parsfix)
@@ -174,12 +173,16 @@ cla_secsse_ml <- function(phy,
                     initparsopt)
     optimpars <- c(tol, maxiter)
 
+    num_modeled_traits <- length(idparslist[[1]]) / num_concealed_states
+
     setting_calculation <- build_initStates_time(phy,
                                                  traits,
                                                  num_concealed_states,
                                                  sampling_fraction,
                                                  is_complete_tree,
-                                                 mus)
+                                                 mus,
+                                                 num_modeled_traits)
+
     initloglik <- secsse_loglik_choosepar(trparsopt = trparsopt,
                                           trparsfix = trparsfix,
                                           idparsopt = idparsopt,
@@ -204,15 +207,13 @@ cla_secsse_ml <- function(phy,
                                           atol = atol,
                                           rtol = rtol,
                                           method = method)
-    cat("The loglikelihood for the initial parameter values is",
-        initloglik, "\n")
+    # Function here
+    print_init_ll(initloglik = initloglik, verbose = verbose)
     if (initloglik == -Inf) {
         stop("The initial parameter values have a likelihood that is 
              equal to 0 or below machine precision. 
              Try again with different initial values.")
     } else {
-        cat("Optimizing the likelihood - this may take a while.", "\n")
-        utils::flush.console()
         out <- DDD::optimizer(optimmethod = optimmethod,
                               optimpars = optimpars,
                               fun = secsse_loglik_choosepar,
@@ -240,7 +241,7 @@ cla_secsse_ml <- function(phy,
                               method = method)
         if (out$conv != 0) {
             stop("Optimization has not converged. 
-                 Try again with different initial values.\n")
+                 Try again with different initial values.")
         } else {
             ml_pars1 <- secsse_transform_parameters(as.numeric(unlist(out$par)),
                                                    trparsfix,
