@@ -102,13 +102,12 @@
 #'  par_6 <- par_3 * factor_1
 #'}
 #'
-#'tol = c(1e-04, 1e-05, 1e-07)
+#'tol = c(1e-02, 1e-03, 1e-04)
 #'maxiter = 1000 * round((1.25)^length(idparsopt))
-#'optimmethod = "simplex"
+#'optimmethod = "subplex"
 #'cond<-"proper_cond"
 #'root_state_weight <- "proper_weights"
 #'sampling_fraction <- c(1,1,1)
-#'\dontrun{
 #'model <- secsse_ml_func_def_pars(phylotree,
 #'traits,
 #'num_concealed_states,
@@ -128,7 +127,6 @@
 #'maxiter,
 #'optimmethod,
 #'num_cycles = 1)
-#'}
 #'# ML -136.5796
 #' @export
 secsse_ml_func_def_pars <- function(phy,
@@ -154,8 +152,8 @@ secsse_ml_func_def_pars <- function(phy,
                                     loglik_penalty = 0,
                                     is_complete_tree = FALSE,
                                     num_threads = 1,
-                                    atol = 1e-12,
-                                    rtol = 1e-12,
+                                    atol = 1e-8,
+                                    rtol = 1e-6,
                                     method = "odeint::bulirsch_stoer") {
 
     structure_func <- list()
@@ -189,8 +187,8 @@ secsse_ml_func_def_pars <- function(phy,
     }
 
     if (is.matrix(traits)) {
-        cat("You are setting a model where some species had more than 
-            one trait state \n")
+        warning("You are setting a model where some species had more than 
+            one trait state")
     }
 
     if (length(initparsopt) != length(idparsopt)) {
@@ -227,12 +225,9 @@ secsse_ml_func_def_pars <- function(phy,
     if (anyDuplicated(c(unique(sort(
         as.vector(idparslist[[3]])
     )), idparsfix[which(parsfix == 0)])) != 0) {
-        cat("You set some transitions as impossible to happen", "\n")
+        warning("You set some transitions as impossible to happen")
     }
 
-    cat("Calculating the likelihood for the initial parameters.", "\n")
-    utils::flush.console()
-
     initparsopt2 <- c(initparsopt, initfactors)
 
     trparsopt <- initparsopt2 / (1 + initparsopt2)
@@ -281,16 +276,12 @@ secsse_ml_func_def_pars <- function(phy,
             rtol = rtol,
             method = method
         )
-    cat("The loglikelihood for the initial parameter values is",
-        initloglik,
-        "\n")
+    print_init_ll(initloglik = initloglik, verbose = verbose)
     if (initloglik == -Inf) {
       stop("The initial parameter values have a likelihood that is equal to 0 
            or below machine precision. Try again with different initial values."
       )
     } else {
-        cat("Optimizing the likelihood - this may take a while.", "\n")
-        utils::flush.console()
         out <-
             DDD::optimizer(
                 optimmethod = optimmethod,
