@@ -16,7 +16,7 @@ id_paramPos <- function(traits, num_concealed_states) { #noLint
     if (is.matrix(traits)) {
         traits <- traits[, 1]
     }
-
+    
     ly <- length(sort(unique(traits))) * 2 * num_concealed_states
     d <- ly / 2
     idparslist[[1]] <- 1:d
@@ -31,23 +31,23 @@ id_paramPos <- function(traits, num_concealed_states) { #noLint
     Q <- matrix(toMatrix, ncol = d, nrow = d, byrow = TRUE)
     diag(Q) <- NA
     idparslist[[3]] <- Q
-
+    
     lab_states <- rep(as.character(sort(unique(traits))), num_concealed_states)
-
+    
     lab_conceal <- NULL
     for (i in 1:num_concealed_states) {
-
+        
         lab_conceal <- c(lab_conceal,
                          rep(LETTERS[i],
                              length(sort(unique(traits)))))
     }
-
+    
     statesCombiNames <- character()
     for (i in seq_along(lab_states)) {
         statesCombiNames <- c(statesCombiNames,
                               paste0(lab_states[i],
                                      lab_conceal[i]))
-
+        
     }
     colnames(idparslist[[3]]) <- statesCombiNames
     rownames(idparslist[[3]]) <- statesCombiNames
@@ -72,7 +72,7 @@ create_q_matrix <- function(masterBlock,
                 if (diff.conceal == TRUE) {
                     entry <- concealnewQMatr[i, ii]
                 }
-
+                
                 outDiagBlock <- matrix(0,
                                        ncol = ntraits,
                                        nrow = ntraits,
@@ -94,9 +94,14 @@ create_q_matrix <- function(masterBlock,
 #' @param masterBlock matrix of transitions among only examined states, NA in
 #' the main diagonal, used to build the full transition rates matrix.
 #' @param diff.conceal should the concealed states be different? Normally it
-#' should be FALSE.
+#' should be FALSE. E.g. that the transition rates for the concealed states
+#' are different from the transition rates for the examined states.
 #' @return Q matrix that includes both examined and concealed states, it should
 #' be declared as the third element of idparslist.
+#' @description This function expands the Q_matrix, but it does so assuming
+#' that the number of concealed traits is equal to the number of examined 
+#' traits, if you have a different number, you should consider looking at
+#' the function [expand_q_matrix()].
 #' @examples
 #' traits <- sample(c(0,1,2), 45,replace = TRUE) #get some traits
 #' # For a three-state trait
@@ -115,35 +120,34 @@ create_q_matrix <- function(masterBlock,
 #' param_posit[[3]] <- myQ
 #' @export
 q_doubletrans <- function(traits, masterBlock, diff.conceal) {
-
     if (diff.conceal == TRUE &&
         all(floor(masterBlock) == masterBlock, na.rm = TRUE) == FALSE) {
         integersmasterBlock <- floor(masterBlock)
         factorBlock <- signif(masterBlock - integersmasterBlock, digits = 2)
-
+        
         factorstoExpand <- unique(sort(c(factorBlock)))
         factorstoExpand <- factorstoExpand[factorstoExpand > 0]
         newshareFac <-
             (max(factorstoExpand * 10) + 1):(max(factorstoExpand * 10) +
                                                  length(factorstoExpand))
         newshareFac <- newshareFac / 10
-
+        
         for (iii in seq_along(newshareFac)) {
             factorBlock[which(factorBlock == factorstoExpand[iii])] <-
-                                                             newshareFac[iii]
+                newshareFac[iii]
         }
-
+        
         ntraits <- length(sort(unique(traits)))
         uniqParQ <- sort(unique(c(floor(masterBlock))))
         uniqParQ2 <- uniqParQ[which(uniqParQ > 0)]
         concealnewQ <- (max(uniqParQ2) + 1):(max(uniqParQ2) + length(uniqParQ2))
-
+        
         for (iii in seq_along(concealnewQ)) {
             integersmasterBlock[which(integersmasterBlock == uniqParQ2[iii])] <-
-                                                             concealnewQ[iii]
+                concealnewQ[iii]
         }
         concealnewQMatr <- integersmasterBlock + factorBlock
-
+        
         Q <- create_q_matrix(masterBlock,
                              concealnewQMatr,
                              ntraits,
@@ -158,7 +162,7 @@ q_doubletrans <- function(traits, masterBlock, diff.conceal) {
             uniqParQ2
             concealnewQMatr[concealnewQMatr == uniqParQ2[I]] <- concealnewQ[I]
         }
-
+        
         Q <- create_q_matrix(masterBlock,
                              concealnewQMatr,
                              ntraits,
@@ -188,23 +192,25 @@ sortingtraits <- function(traitinfo, phy) {
         stop("Number of species in the tree must be the same as
              in the trait file")
     }
-
+    
     if (identical(as.character(sort(phy$tip.label)),
                   as.character(sort(traitinfo[, 1]))) == FALSE) {
         mismatch <- match(as.character(sort(traitinfo[, 1])),
                           as.character(sort(phy$tip.label)))
         mismatched <- (sort(traitinfo[, 1]))[which(is.na(mismatch))]
-        stop(cat("Mismatch on tip labels and taxa names, check the species:",
-                 mismatched))
+        stop(
+            paste(c("Mismatch on tip labels and taxa names, check the species:",
+                    mismatched), collapse = " ")
+        )
     }
-
+    
     traitinfo <- traitinfo[match(phy$tip.label, traitinfo[, 1]), ]
     traitinfo[, 1] == phy$tip.label
-
+    
     if (ncol(traitinfo) == 2) {
         traits <- as.numeric(traitinfo[, 2])
     }
-
+    
     if (ncol(traitinfo) > 2) {
         traits <- NULL
         for (i in 1:(ncol(traitinfo) - 1)) {
@@ -232,7 +238,7 @@ cla_id_paramPos <- function(traits, num_concealed_states) {
     if (is.matrix(traits)) {
         traits <- traits[, 1]
     }
-
+    
     ly <- length(sort(unique(traits))) * 2 * num_concealed_states
     d <- ly / 2
     toMatrix <- 1
@@ -240,38 +246,38 @@ cla_id_paramPos <- function(traits, num_concealed_states) {
     for (i in 1:d) {
         toMatrix <- c(toMatrix,
                       matPos[(i * d - (d - 1)):((i * d - (d - 1)) + d)])
-
+        
     }
     toMatrix <- toMatrix[1:d^2]
     Q <- matrix(toMatrix, ncol = d, nrow = d, byrow = TRUE)
     diag(Q) <- NA
     lab_states <- rep(as.character(sort(unique(traits))), num_concealed_states)
-
+    
     lab_conceal <- NULL
     for (i in 1:num_concealed_states) {
-
+        
         lab_conceal <- c(lab_conceal,
                          rep(LETTERS[i],
                              length(sort(unique(traits)))))
     }
-
-
+    
+    
     statesCombiNames <- character()
     for (i in seq_along(lab_states)) {
         statesCombiNames <- c(statesCombiNames,
                               paste0(lab_states[i],
                                      lab_conceal[i]))
     }
-
+    
     idparslist[[1]] <- matrix(0, ncol = d, nrow = 4)
     idparslist[[2]] <- (d + 1):ly
     idparslist[[3]] <- Q
-
+    
     rownames(idparslist[[1]]) <- c("dual_inheritance",
                                    "single_inheritance",
                                    "dual_symmetric_transition",
                                    "dual_asymmetric_transition")
-
+    
     colnames(idparslist[[1]]) <- statesCombiNames
     colnames(idparslist[[3]]) <- statesCombiNames
     rownames(idparslist[[3]]) <- statesCombiNames
@@ -290,9 +296,36 @@ cla_id_paramPos <- function(traits, num_concealed_states) {
 #' @return A list of lambdas, its length would be the same than the number of
 #' trait states * num_concealed_states..
 #' @export
+#' @examples
+#' set.seed(13)
+#' phylotree <- ape::rcoal(12, tip.label = 1:12)
+#' traits <- sample(c(0, 1, 2),
+#'                  ape::Ntip(phylotree), replace = TRUE)
+#' num_concealed_states <- 3
+#' # the idparlist for a ETD model (dual state inheritance model of evolution)
+#' # would be set like this:
+#' idparlist <- secsse::cla_id_paramPos(traits, num_concealed_states)
+#' lambd_and_modeSpe <- idparlist$lambdas
+#' lambd_and_modeSpe[1, ] <- c(1, 1, 1, 2, 2, 2, 3, 3, 3)
+#' idparlist[[1]] <- lambd_and_modeSpe
+#' idparlist[[2]][] <- 0
+#' masterBlock <- matrix(4, ncol = 3, nrow = 3, byrow = TRUE)
+#' diag(masterBlock) <- NA
+#' idparlist[[3]] <- q_doubletrans(traits, masterBlock, diff.conceal = FALSE)
+#' # Now, internally, clasecsse sorts the lambda matrices, so they look like
+#' #  a list with 9 matrices, corresponding to the 9 states
+#' # (0A,1A,2A,0B, etc)
+#' 
+#' parameter <- idparlist
+#' lambda_and_modeSpe <- parameter$lambdas
+#' lambda_and_modeSpe[1, ] <- c(0.2, 0.2, 0.2, 0.4, 0.4, 0.4, 0.01, 0.01, 0.01)
+#' parameter[[1]] <- prepare_full_lambdas(traits, num_concealed_states,
+#'                                        lambda_and_modeSpe)
 prepare_full_lambdas <- function(traits,
                                  num_concealed_states,
                                  lambd_and_modeSpe) {
+    if (is.list(lambd_and_modeSpe)) return(lambd_and_modeSpe)
+    
     num_exami <- length(sort(unique(traits)))
     mat_size <- num_exami * num_concealed_states
     posib_trans <- matrix(1,
@@ -303,28 +336,27 @@ prepare_full_lambdas <- function(traits,
     posib_trans <- q_doubletrans(traits,
                                  masterBlock = posib_trans,
                                  diff.conceal = FALSE)
-
+    
     full_lambdas <- list()
-
     for (jj in 1:mat_size) {
         # dual_state_inhe
         m1 <- matrix(0, ncol = mat_size, nrow = mat_size)
         m1[jj, jj] <- as.numeric(lambd_and_modeSpe[, jj][1])
-
+        
         # single_state_inhe
         m2 <- matrix(0, ncol = mat_size, nrow = mat_size)
         m2[, jj] <- posib_trans[jj, ]
         m2[jj, jj] <- 0
         m2[m2 == 1] <- as.numeric(lambd_and_modeSpe[, jj][2])
         # symet_state_emerge
-
+        
         m3 <- matrix(0, ncol = mat_size, nrow = mat_size)
-
+        
         diag(m3) <- posib_trans[jj, ]
         m3[jj, jj] <- 0
         m3[m3 == 1] <- as.numeric(lambd_and_modeSpe[, jj][3])
         # symet_state_emerge
-
+        
         m4 <- matrix(0, ncol = mat_size, nrow = mat_size)
         for (i in seq_along(which(posib_trans[jj, ] == 1))) {
             m4[which(posib_trans[jj, ] == 1)[i], ] <- posib_trans[jj, ]
@@ -334,7 +366,7 @@ prepare_full_lambdas <- function(traits,
         diag(m4) <- 0
         m4[is.na(m4)] <- 0
         m4[m4 == 1] <- as.numeric(lambd_and_modeSpe[, jj][4])
-
+        
         full_lambdas[[jj]] <- m1 + m2 + m3 + m4
     }
     return(full_lambdas)
@@ -348,7 +380,7 @@ normalize_loglik <- function(probs, loglik) {
     sumabsprobs <- sum(abs(probs))
     probs <- probs / sumabsprobs
     loglik <- loglik + log(sumabsprobs)
-    cat(probs, loglik, "\n")
+    message(paste(c(probs, loglik), collapse = " "))
     return(list(probs = probs, loglik = loglik))
 }
 
